===============================
Nameless
===============================


.. image:: http://img.shields.io/travis/ionelmc/python-nameless/master.png
    :alt: Build Status
    :target: https://travis-ci.org/ionelmc/python-nameless

.. image:: http://img.shields.io/coveralls/ionelmc/python-nameless.png
    :alt: Coverage Status
    :target: https://coveralls.io/r/ionelmc/python-nameless

.. image:: http://img.shields.io/pypi/v/nameless.png
    :alt: PYPI Package
    :target: https://pypi.python.org/pypi/nameless

.. image:: http://img.shields.io/pypi/dm/nameless.png
    :alt: PYPI Package
    :target: https://pypi.python.org/pypi/nameless

An example package. Replace this with a proper project description.

* Free software: BSD license
* Documentation: http://python-nameless.readthedocs.org.

Installation
============

::

    pip install nameless

Documentation
=============

https://python-nameless.readthedocs.org/

Development
===========

To run the all tests run::

    tox
